@@ -276,6 +276,21 @@ static bool try_apache_listing(file_info &info,const char *str)
    }
    return false;
 }
+static bool try_apache_listing_iso(file_info &info,const char *str)
+{
+   info.clear();
+
+   // apache listing with ISO time: YYYY-MM-DD hh:mm size
+   int n=sscanf(str,"%4d-%2d-%2d %2d:%2d %30s",
+	       &info.year,&info.month,&info.day,
+	       &info.hour,&info.minute,info.size_str);
+   if(n==6 && (info.size_str[0]=='-' || is_ascii_digit(info.size_str[0])))
+   {
+      debug("apache listing matched (ISO time)");
+      return true;
+   }
+   return false;
+}
 static bool try_apache_listing_unusual(file_info &info,const char *str)
 {
    info.clear();
@@ -579,6 +594,7 @@ static bool try_csm_proxy(file_info &info,const char *str)
 	      Log::global->Format(10,
 		      "* try_csm_proxy: unknown file type '%s'\n",
 		      additional_file_info);
+	      return false;
 	  }
       }
    }
@@ -709,9 +725,10 @@ static int parse_html(const char *buf,int buf_len,bool eof,const Ref<Buffer>& li
 	 { "img", "lowsrc" },
 	 { "input", "src" },
 	 { "layer", "src" },
-	 { "table", "background"},
-	 { "th", "background"},
-	 { "td", "background"},
+	 { "table", "background" },
+	 { "th", "background" },
+	 { "td", "background" },
+	 { "link", "href" },
 	 /* Tags below this line are treated specially.  */
 	 { "base", "href" },
 	 { "meta", "content" },
@@ -743,6 +760,14 @@ static int parse_html(const char *buf,int buf_len,bool eof,const Ref<Buffer>& li
 
    decode_amps(link_target);  // decode all &amp; and similar
 
+   // inherit the protocol if omitted
+   if(link_target.begins_with("//") && prefix && prefix->proto) {
+      xstring& new_link=xstring::get_tmp("")
+	 .append_url_encoded(prefix->proto,URL_UNSAFE,0)
+	 .append(':').append(link_target);
+      link_target.swap(new_link);
+   }
+
    if(hftp)
    {
       // workaround proxy bugs.
@@ -991,6 +1016,7 @@ parse_url_again:
       remove_tags(str);
 
       if(try_apache_listing(info,str)		&& info.validate()) goto got_info;
+      if(try_apache_listing_iso(info,str)	&& info.validate()) goto got_info;
       if(try_apache_listing_unusual(info,str)	&& info.validate()) goto got_info;
       if(try_netscape_proxy(info,str)		&& info.validate()) goto got_info;
       if(try_squid_eplf(info,str) && info.validate())
@@ -1390,10 +1416,16 @@ FileSet *Http::ParseLongList(const char *b,int len,int *err) const
    if(err)
       *err=0;
 
+   FileSet *set=0;
+
    if(len>5 && !strncmp(b,"<?xml",5))
-      return HttpListInfo::ParseProps(b,len,GetCwd());
+      set=HttpListInfo::ParseProps(b,len,GetCwd());
+
+   if(!set)
+      set=new FileSet;
+   if(set->count()>0)
+      return set;
 
-   FileSet *set=new FileSet;
    ParsedURL prefix(GetConnectURL());
    xstring_c base_href;
    for(;;)
