@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2017 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -272,7 +272,9 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 "If entry type cannot be determined, it will be included in the list.\n"
 	 " -f  plain files (default)\n"
 	 " -d  directories\n"
-	 " -a  all types\n")},
+	 " -a  all types\n"
+	 " --exist      return zero exit code when the patterns expand to non-empty list\n"
+	 " --not-exist  return zero exit code when the patterns expand to an empty list\n")},
    {"help",    cmd_help,   N_("help [<cmd>]"),
 	 N_("Print help for command <cmd>, or list of available commands\n")},
    {"jobs",    cmd_jobs,   "jobs [-v] [<job_no...>]",
@@ -2169,8 +2171,7 @@ CMD(debug)
       truncate(debug_file_name,0);
 
    const char *c="debug";
-   if(debug_file_name)
-      ResMgr::Set("log:file",c,debug_file_name);
+   ResMgr::Set("log:file",c,debug_file_name?debug_file_name:"");
 
    ResMgr::Set("log:enabled",c,enabled?"yes":"no");
    if(enabled)
@@ -2716,7 +2717,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("LFTP | Version %s | Copyright (c) 1996-%d Alexander V. Lukyanov\n"),VERSION,2016);
+      _("LFTP | Version %s | Copyright (c) 1996-%d Alexander V. Lukyanov\n"),VERSION,2017);
    printf("\n");
    printf(
       _("LFTP is free software: you can redistribute it and/or modify\n"
